summaryrefslogtreecommitdiffstats
path: root/hugolib/site_new.go
diff options
context:
space:
mode:
Diffstat (limited to 'hugolib/site_new.go')
-rw-r--r--hugolib/site_new.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/hugolib/site_new.go b/hugolib/site_new.go
index 5a5811958..21d5ace96 100644
--- a/hugolib/site_new.go
+++ b/hugolib/site_new.go
@@ -484,10 +484,10 @@ func (s *Site) BuildDrafts() bool {
return s.conf.BuildDrafts
}
// Deprecated: Use hugo.IsMultiLingual instead.
func (s *Site) IsMultiLingual() bool {
- hugo.Deprecate(".Site.IsMultiLingual", "Use hugo.IsMultiLingual instead.", "v0.124.0")
- return s.h.isMultiLingual()
+ hugo.Deprecate(".Site.IsMultiLingual", "Use hugo.IsMultilingual instead.", "v0.124.0")
+ return s.h.isMultilingual()
}
func (s *Site) LanguagePrefix() string {
@@ -484,10 +484,10 @@ func (s *Site) BuildDrafts() bool {
return s.conf.BuildDrafts
}
-// Deprecated: Use hugo.IsMultiLingual instead.
+// Deprecated: Use hugo.IsMultilingual instead.
func (s *Site) IsMultiLingual() bool {